@@ -154,9 +154,7 @@ void CollectionIndexer::remove(const Akonadi::Collection &col)
     }
 }
 
-void CollectionIndexer::move(const Akonadi::Collection &collection,
-                             const Akonadi::Collection &from,
-                             const Akonadi::Collection &to)
+void CollectionIndexer::move(const Akonadi::Collection &collection, const Akonadi::Collection &from, const Akonadi::Collection &to)
 {
     Q_UNUSED(from);
     Q_UNUSED(to);
