@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2019 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -23,21 +23,19 @@
 
 using namespace Akonadi::Search;
 AkonadiSearchDebugSearchJob::AkonadiSearchDebugSearchJob(QObject *parent)
-    : QObject(parent),
-      mProcess(nullptr)
+    : QObject(parent)
+    , mProcess(nullptr)
 {
-
 }
 
 AkonadiSearchDebugSearchJob::~AkonadiSearchDebugSearchJob()
 {
-
 }
 
 void AkonadiSearchDebugSearchJob::start()
 {
     // "delve" is also a name of Go debugger, some distros prefer xapian-delve
-    // for that reason, so try that first and fallback to "delve" 
+    // for that reason, so try that first and fallback to "delve"
     QString delvePath = QStandardPaths::findExecutable(QStringLiteral("xapian-delve"));
     if (delvePath.isEmpty()) {
         delvePath = QStandardPaths::findExecutable(QStringLiteral("delve"));
@@ -93,4 +91,3 @@ void AkonadiSearchDebugSearchJob::setSearchPath(const QString &path)
 {
     mPath = path;
 }
-
